@@ -211,7 +211,7 @@ class DesktopLibrary(AppiumLibrary):
         ``error`` can be used to override the default error message.
 
         See `introduction` for details about locating elements."""
-        self.wait_until_page_contains_element(locator, timeout, error)
+        self._wait_until_page_contains_element(locator, timeout, error)
         self.clear_text(locator)
 
     def click_element(self, locator):
@@ -235,7 +235,7 @@ class DesktopLibrary(AppiumLibrary):
         See `introduction` for details about locating elements.
         
         Use `Wait For And Mouse Over And Click Element` if this keyword gives issues in the application."""
-        self.wait_until_page_contains_element(locator, timeout, error)
+        self._wait_until_page_contains_element(locator, timeout, error)
         self.click_element(locator)
 
     @keyword("Click Text")
@@ -248,7 +248,7 @@ class DesktopLibrary(AppiumLibrary):
     def wait_for_and_click_text(self, text, exact_match=False, timeout=None, error=None):
         """*DEPRECATED in DesktopLibrary 2.4.0* Use `Wait For And Click Element` with the ``name`` prefix instead.
         """
-        self.wait_until_page_contains(text, timeout, error)
+        self._wait_until_page_contains(text, timeout, error)
         self.click_text(text, exact_match)
 
     @keyword("Wait For And Input Password")
@@ -261,7 +261,7 @@ class DesktopLibrary(AppiumLibrary):
 
         The difference between this keyword and `Wait For And Input Text` is that this keyword
         does not log the given password. See `introduction` for details about locating elements."""
-        self.wait_until_page_contains_element(locator, timeout, error)
+        self._wait_until_page_contains_element(locator, timeout, error)
         self.input_password(locator, text)
 
     @keyword("Wait For And Input Text")
@@ -273,7 +273,7 @@ class DesktopLibrary(AppiumLibrary):
         ``error`` can be used to override the default error message.
 
         See `introduction` for details about locating elements."""
-        self.wait_until_page_contains_element(locator, timeout, error)
+        self._wait_until_page_contains_element(locator, timeout, error)
         self.input_text(locator, text)
 
     @keyword("Wait For And Long Press")
@@ -285,7 +285,7 @@ class DesktopLibrary(AppiumLibrary):
         ``error`` can be used to override the default error message.
 
         See `introduction` for details about locating elements."""
-        self.wait_until_page_contains_element(locator, timeout, error)
+        self._wait_until_page_contains_element(locator, timeout, error)
         self.long_press(locator, duration)
 
     @keyword("Wait Until Element Contains")
@@ -300,7 +300,7 @@ class DesktopLibrary(AppiumLibrary):
         `Wait Until Page Does Not Contain`
         `Wait Until Page Does Not Contain Element`
         """
-        self.wait_until_page_contains_element(locator, timeout, error)
+        self._wait_until_page_contains_element(locator, timeout, error)
         self.element_should_contain_text(locator, text, error)
 
     @keyword("Wait Until Element Does Not Contain")
@@ -316,7 +316,7 @@ class DesktopLibrary(AppiumLibrary):
         `Wait Until Page Does Not Contain`
         `Wait Until Page Does Not Contain Element`
         """
-        self.wait_until_page_contains_element(locator, timeout, error)
+        self._wait_until_page_contains_element(locator, timeout, error)
         self.element_should_not_contain_text(locator, text, error)
 
     @keyword("Wait Until Element Is Enabled")
@@ -329,7 +329,7 @@ class DesktopLibrary(AppiumLibrary):
 
         See also `Wait Until Element Is Disabled`
         """
-        self.wait_until_page_contains_element(locator, timeout, error)
+        self._wait_until_page_contains_element(locator, timeout, error)
         self.element_should_be_enabled(locator)
 
     @keyword("Wait Until Element Is Disabled")
@@ -342,7 +342,7 @@ class DesktopLibrary(AppiumLibrary):
 
         See also `Wait Until Element Is Disabled`
         """
-        self.wait_until_page_contains_element(locator, timeout, error)
+        self._wait_until_page_contains_element(locator, timeout, error)
         self.element_should_be_disabled(locator)
 
     @keyword("Mouse Over Element")
@@ -367,7 +367,7 @@ class DesktopLibrary(AppiumLibrary):
 
         ``x_offset`` and ``y_offset`` can be used to move to a specific coordinate.
         """
-        self.wait_until_page_contains_element(locator, timeout, error)
+        self._wait_until_page_contains_element(locator, timeout, error)
         self.mouse_over_element(locator, x_offset, y_offset)
 
     @keyword("Mouse Over And Click Element")
@@ -405,7 +405,7 @@ class DesktopLibrary(AppiumLibrary):
 
         ``x_offset`` and ``y_offset`` can be used to move to a specific coordinate.
         """
-        self.wait_until_page_contains_element(locator, timeout, error)
+        self._wait_until_page_contains_element(locator, timeout, error)
         self.mouse_over_and_click_element(locator, double_click, x_offset, y_offset)
 
     @keyword("Mouse Over Text")
@@ -422,7 +422,7 @@ class DesktopLibrary(AppiumLibrary):
     def wait_for_and_mouse_over_text(self, text, exact_match=False, timeout=None, error=None, x_offset=0, y_offset=0):
         """*DEPRECATED in DesktopLibrary 2.4.0* Use `Wait For And Mouse Over Element` with the ``name`` prefix instead.
         """
-        self.wait_until_page_contains(text, timeout, error)
+        self._wait_until_page_contains(text, timeout, error)
         self.mouse_over_text(text, exact_match, x_offset, y_offset)
 
     @keyword("Mouse Over And Click Text")
@@ -446,7 +446,7 @@ class DesktopLibrary(AppiumLibrary):
         """*DEPRECATED in DesktopLibrary 2.4.0* Use `Wait For And Mouse Over And Click Element` with the ``name``
          prefix instead.
         """
-        self.wait_until_page_contains(text, timeout, error)
+        self._wait_until_page_contains(text, timeout, error)
         self.mouse_over_and_click_text(text, exact_match, double_click, x_offset, y_offset)
 
     @keyword("Mouse Over By Offset")
@@ -676,3 +676,15 @@ class DesktopLibrary(AppiumLibrary):
                 prefix = locator_parts[0].strip().lower()
                 criteria = locator_parts[2].strip()
         return prefix, criteria
+    
+    def _wait_until_page_contains(self, text, timeout=None, error=None):
+        """Internal version to avoid duplicate screenshots"""
+        if not error:
+            error = "Text '%s' did not appear in <TIMEOUT>" % text
+        self._wait_until(timeout, error, self._is_text_present, text)
+
+    def _wait_until_page_contains_element(self, locator, timeout=None, error=None):
+        """Internal version to avoid duplicate screenshots"""
+        if not error:
+            error = "Element '%s' did not appear in <TIMEOUT>" % locator
+        self._wait_until(timeout, error, self._is_element_present, locator)
